<?php

namespace Newage\Newsfeed\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Newage\Newsfeed\Interfaces\NewsfeedRepositoryInterface;

class NewsfeedPublicController extends BaseController
{
    // use NewsfeedWorkflow;

    /**
     * Constructor.
     *
     * @param type \Newage\Newsfeed\Interfaces\NewsfeedRepositoryInterface $newsfeed
     *
     * @return type
     */
    public function __construct(NewsfeedRepositoryInterface $newsfeed)
    {
        $this->repository = $newsfeed;
        parent::__construct();
    }

    /**
     * Show newsfeed's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $newsfeeds = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$newsfeed::$newsfeed.names'))
            ->view('$newsfeed::public.newsfeed.index')
            ->data(compact('$newsfeeds'))
            ->output();
    }

    /**
     * Show newsfeed's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $newsfeeds = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$newsfeed::$newsfeed.names'))
            ->view('$newsfeed::public.newsfeed.index')
            ->data(compact('$newsfeeds'))
            ->output();
    }

    /**
     * Show newsfeed.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $newsfeed = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$newsfeed->name . trans('$newsfeed::$newsfeed.name'))
            ->view('$newsfeed::public.newsfeed.show')
            ->data(compact('$newsfeed'))
            ->output();
    }

}
