<?php

namespace Newage\Newsfeed\Policies;

use Litepie\User\Contracts\UserPolicy;
use Newage\Newsfeed\Models\Newsfeed;

class NewsfeedPolicy
{

    /**
     * Determine if the given user can view the newsfeed.
     *
     * @param UserPolicy $user
     * @param Newsfeed $newsfeed
     *
     * @return bool
     */
    public function view(UserPolicy $user, Newsfeed $newsfeed)
    {
        if ($user->canDo('newsfeed.newsfeed.view') && $user->isAdmin()) {
            return true;
        }

        return $newsfeed->user_id == user_id() && $newsfeed->user_type == user_type();
    }

    /**
     * Determine if the given user can create a newsfeed.
     *
     * @param UserPolicy $user
     * @param Newsfeed $newsfeed
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('newsfeed.newsfeed.create');
    }

    /**
     * Determine if the given user can update the given newsfeed.
     *
     * @param UserPolicy $user
     * @param Newsfeed $newsfeed
     *
     * @return bool
     */
    public function update(UserPolicy $user, Newsfeed $newsfeed)
    {
        if ($user->canDo('newsfeed.newsfeed.edit') && $user->isAdmin()) {
            return true;
        }

        return $newsfeed->user_id == user_id() && $newsfeed->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given newsfeed.
     *
     * @param UserPolicy $user
     * @param Newsfeed $newsfeed
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Newsfeed $newsfeed)
    {
        return $newsfeed->user_id == user_id() && $newsfeed->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given newsfeed.
     *
     * @param UserPolicy $user
     * @param Newsfeed $newsfeed
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Newsfeed $newsfeed)
    {
        if ($user->canDo('newsfeed.newsfeed.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given newsfeed.
     *
     * @param UserPolicy $user
     * @param Newsfeed $newsfeed
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Newsfeed $newsfeed)
    {
        if ($user->canDo('newsfeed.newsfeed.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
