<?php

namespace Newage\Newsfeed\Providers;

use Illuminate\Support\ServiceProvider;

class NewsfeedServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'newsfeed');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'newsfeed');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('newage.newsfeed', function ($app) {
            return $this->app->make('Newage\Newsfeed\Newsfeed');
        });

        // Bind Newsfeed to repository
        $this->app->bind(
            'Newage\Newsfeed\Interfaces\NewsfeedRepositoryInterface',
            \Newage\Newsfeed\Repositories\Eloquent\NewsfeedRepository::class
        );
        // Bind Source to repository
        $this->app->bind(
            'Newage\Newsfeed\Interfaces\SourceRepositoryInterface',
            \Newage\Newsfeed\Repositories\Eloquent\SourceRepository::class
        );

        $this->app->register(\Newage\Newsfeed\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Newage\Newsfeed\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['newage.newsfeed'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('newage/newsfeed.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/newsfeed')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/newsfeed')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
